0.4.0
-----

* Moved project to Github.
* Use Travis-CI for continuous integration and deployment.
* Use setuptools_scm for tagging releases.

0.3.0
-----

* Fixes for Python 3. Tests now pass on Python 3.

0.2.0
-----

* Improved compatibility with Python 3
* Add support for the style parameter on a column.
* Add support for 'best fit' parameter on a column.

0.1.6
-----

* Performance improvements (memory and speed)

